# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ItemRankResponse(Model):
    """ItemRankResponse.

    :param type: The item type
    :type type: str
    :param id: The item identifier
    :type id: int
    :param display: The item display name
    :type display: str
    :param secondary_display: The item formated value
    :type secondary_display: str
    :param value: The item value
    :type value: float
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'id': {'key': 'id', 'type': 'int'},
        'display': {'key': 'display', 'type': 'str'},
        'secondary_display': {'key': 'secondaryDisplay', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, *, type: str=None, id: int=None, display: str=None, secondary_display: str=None, value: float=None, **kwargs) -> None:
        super(ItemRankResponse, self).__init__(**kwargs)
        self.type = type
        self.id = id
        self.display = display
        self.secondary_display = secondary_display
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WatticsDataPointChild(Model):
    """WatticsDataPointChild.

    :param wattics_data_point_id: The identifier for a Wattics meter
    :type wattics_data_point_id: int
    :param wattics_data_point_info: The name for a Wattics meter
    :type wattics_data_point_info: str
    """

    _attribute_map = {
        'wattics_data_point_id': {'key': 'watticsDataPointId', 'type': 'int'},
        'wattics_data_point_info': {'key': 'watticsDataPointInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(WatticsDataPointChild, self).__init__(**kwargs)
        self.wattics_data_point_id = kwargs.get('wattics_data_point_id', None)
        self.wattics_data_point_info = kwargs.get('wattics_data_point_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGVersion(Model):
    """GHGVersion.

    :param effective_date: Effective Date
    :type effective_date: datetime
    :param source: Source
    :type source: str
    :param gases: List of gases per version.
    :type gases: list[~energycap.sdk.models.GHGGas]
    """

    _attribute_map = {
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'source': {'key': 'source', 'type': 'str'},
        'gases': {'key': 'gases', 'type': '[GHGGas]'},
    }

    def __init__(self, **kwargs):
        super(GHGVersion, self).__init__(**kwargs)
        self.effective_date = kwargs.get('effective_date', None)
        self.source = kwargs.get('source', None)
        self.gases = kwargs.get('gases', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CreateUtilityPlatformMeter(Model):
    """CreateUtilityPlatformMeter.

    All required parameters must be populated in order to send to Azure.

    :param meter_code: Required. The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
    }

    def __init__(self, *, meter_code: str, **kwargs) -> None:
        super(CreateUtilityPlatformMeter, self).__init__(**kwargs)
        self.meter_code = meter_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGYearlyEmissions(Model):
    """GHGYearlyEmissions.

    :param year: The year this data belongs to.
    :type year: str
    :param total_yearly_emissions: The total emissions for this year, in CO2
     Equivalent
    :type total_yearly_emissions: float
    :param target_performance_percentage: A percentage value that represents
     how close to the target year this year's data is. A positive value
     means the current year is over the target, a negative value means the
     current year is under the target.
     Field is null if target data is not available.
    :type target_performance_percentage: float
    :param yearly_emissions_by_gas_type: The total emissions for this year,
     grouped by gas type.
    :type yearly_emissions_by_gas_type:
     list[~energycap.sdk.models.GHGGroupEmissions]
    :param yearly_emissions_by_group: The total emissions for this year,
     grouped by Scope, Commodity, or Scope Category.
    :type yearly_emissions_by_group:
     list[~energycap.sdk.models.GHGGroupEmissions]
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'total_yearly_emissions': {'key': 'totalYearlyEmissions', 'type': 'float'},
        'target_performance_percentage': {'key': 'targetPerformancePercentage', 'type': 'float'},
        'yearly_emissions_by_gas_type': {'key': 'yearlyEmissionsByGasType', 'type': '[GHGGroupEmissions]'},
        'yearly_emissions_by_group': {'key': 'yearlyEmissionsByGroup', 'type': '[GHGGroupEmissions]'},
    }

    def __init__(self, **kwargs):
        super(GHGYearlyEmissions, self).__init__(**kwargs)
        self.year = kwargs.get('year', None)
        self.total_yearly_emissions = kwargs.get('total_yearly_emissions', None)
        self.target_performance_percentage = kwargs.get('target_performance_percentage', None)
        self.yearly_emissions_by_gas_type = kwargs.get('yearly_emissions_by_gas_type', None)
        self.yearly_emissions_by_group = kwargs.get('yearly_emissions_by_group', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryObservationTypeChild(Model):
    """BillEntryObservationTypeChild.

    :param observation_type_id: The observation type identifier
    :type observation_type_id: int
    :param observation_type_code: The observation type code
    :type observation_type_code: str
    :param observation_type_info: The observation type name
    :type observation_type_info: str
    """

    _attribute_map = {
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'observation_type_info': {'key': 'observationTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, observation_type_id: int=None, observation_type_code: str=None, observation_type_info: str=None, **kwargs) -> None:
        super(BillEntryObservationTypeChild, self).__init__(**kwargs)
        self.observation_type_id = observation_type_id
        self.observation_type_code = observation_type_code
        self.observation_type_info = observation_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ObservationTypeChild(Model):
    """ObservationTypeChild.

    :param noun_id: The identifier for the observation type's noun
    :type noun_id: int
    :param noun_code: The observation type's noun code
    :type noun_code: str
    :param credit: Indicates the type of credit for the observation type.
     Possible values include: 1 (Credit), 2 (Debit), 3 (Ignore)
    :type credit: int
    :param observation_type_id: The observation type identifier
    :type observation_type_id: int
    :param observation_type_code: The observation type code
    :type observation_type_code: str
    :param observation_type_info: The observation type info
    :type observation_type_info: str
    """

    _attribute_map = {
        'noun_id': {'key': 'nounId', 'type': 'int'},
        'noun_code': {'key': 'nounCode', 'type': 'str'},
        'credit': {'key': 'credit', 'type': 'int'},
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'observation_type_info': {'key': 'observationTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ObservationTypeChild, self).__init__(**kwargs)
        self.noun_id = kwargs.get('noun_id', None)
        self.noun_code = kwargs.get('noun_code', None)
        self.credit = kwargs.get('credit', None)
        self.observation_type_id = kwargs.get('observation_type_id', None)
        self.observation_type_code = kwargs.get('observation_type_code', None)
        self.observation_type_info = kwargs.get('observation_type_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodRange(Model):
    """General purpose period range DTO.

    :param start_period: The start period for the range
    :type start_period: int
    :param end_period: The end period for the range
    :type end_period: int
    """

    _attribute_map = {
        'start_period': {'key': 'startPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
    }

    def __init__(self, *, start_period: int=None, end_period: int=None, **kwargs) -> None:
        super(PeriodRange, self).__init__(**kwargs)
        self.start_period = start_period
        self.end_period = end_period



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGSettingResponse(Model):
    """GHGSettingResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param scope_category:
    :type scope_category: ~energycap.sdk.models.GHGScopeCategory
    :param factor:
    :type factor: ~energycap.sdk.models.GHGFactor
    :param using_default_settings: If true, this meter is using the default
     GHG settings that were in effect at the time the meter was created
    :type using_default_settings: bool
    :ivar is_configured: Flag indicating whether or not configuration exists
     for this meter.
     If false, EnergyCap.DTO.V202210.GHG.GHGSettingResponseDTO.Factor or
     EnergyCap.DTO.V202210.GHG.GHGSettingResponseDTO.ScopeCategory may be null.
    :vartype is_configured: bool
    """

    _validation = {
        'is_configured': {'readonly': True},
    }

    _attribute_map = {
        'scope_category': {'key': 'scopeCategory', 'type': 'GHGScopeCategory'},
        'factor': {'key': 'factor', 'type': 'GHGFactor'},
        'using_default_settings': {'key': 'usingDefaultSettings', 'type': 'bool'},
        'is_configured': {'key': 'isConfigured', 'type': 'bool'},
    }

    def __init__(self, *, scope_category=None, factor=None, using_default_settings: bool=None, **kwargs) -> None:
        super(GHGSettingResponse, self).__init__(**kwargs)
        self.scope_category = scope_category
        self.factor = factor
        self.using_default_settings = using_default_settings
        self.is_configured = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeSeriesEntity(Model):
    """TimeSeriesEntity.

    :param type:
    :type type: str
    :param id:
    :type id: int
    :param display:
    :type display: str
    :param secondary_display:
    :type secondary_display: str
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'id': {'key': 'id', 'type': 'int'},
        'display': {'key': 'display', 'type': 'str'},
        'secondary_display': {'key': 'secondaryDisplay', 'type': 'str'},
    }

    def __init__(self, *, type: str=None, id: int=None, display: str=None, secondary_display: str=None, **kwargs) -> None:
        super(TimeSeriesEntity, self).__init__(**kwargs)
        self.type = type
        self.id = id
        self.display = display
        self.secondary_display = secondary_display



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AggregatedItemRankResponse(Model):
    """AggregatedItemRankResponse.

    :param period:
    :type period: ~energycap.sdk.models.PeriodRange
    :param display_unit: The display unit of the values
    :type display_unit: str
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.ItemRankResponse]
    """

    _attribute_map = {
        'period': {'key': 'period', 'type': 'PeriodRange'},
        'display_unit': {'key': 'displayUnit', 'type': 'str'},
        'data_details': {'key': 'dataDetails', 'type': '[ItemRankResponse]'},
    }

    def __init__(self, *, period=None, display_unit: str=None, data_details=None, **kwargs) -> None:
        super(AggregatedItemRankResponse, self).__init__(**kwargs)
        self.period = period
        self.display_unit = display_unit
        self.data_details = data_details



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WorkflowSettingsResponse(Model):
    """Workflow settings response.

    :param batch:
    :type batch: ~energycap.sdk.models.BatchWorkflowSettings
    :param approval:
    :type approval: ~energycap.sdk.models.ApprovalWorkflowChild
    :param ap_export:
    :type ap_export: ~energycap.sdk.models.ExportWorkflowChild
    :param gl_export:
    :type gl_export: ~energycap.sdk.models.ExportWorkflowChild
    :param chargeback:
    :type chargeback: ~energycap.sdk.models.ChargebackWorkflowSettings
    :param bill_import:
    :type bill_import: ~energycap.sdk.models.BillImportWorkflowSettings
    """

    _attribute_map = {
        'batch': {'key': 'batch', 'type': 'BatchWorkflowSettings'},
        'approval': {'key': 'approval', 'type': 'ApprovalWorkflowChild'},
        'ap_export': {'key': 'apExport', 'type': 'ExportWorkflowChild'},
        'gl_export': {'key': 'glExport', 'type': 'ExportWorkflowChild'},
        'chargeback': {'key': 'chargeback', 'type': 'ChargebackWorkflowSettings'},
        'bill_import': {'key': 'billImport', 'type': 'BillImportWorkflowSettings'},
    }

    def __init__(self, *, batch=None, approval=None, ap_export=None, gl_export=None, chargeback=None, bill_import=None, **kwargs) -> None:
        super(WorkflowSettingsResponse, self).__init__(**kwargs)
        self.batch = batch
        self.approval = approval
        self.ap_export = ap_export
        self.gl_export = gl_export
        self.chargeback = chargeback
        self.bill_import = bill_import



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MapDashboardSettingsResponse(Model):
    """MapDashboardSettingsResponse.

    :param title: The title of the dashboard. Maximum length of 255
     characters.
    :type title: str
    :param description: The description of the dashboard. Maximum length of
     255 characters.
    :type description: str
    :param show_cost: Flag to indicate if Cost data is shown on the dashboard.
    :type show_cost: bool
    :param show_use: Flag to indicate if Use data is shown on the dashboard.
    :type show_use: bool
    :param show_ghg: Flag to indicate if Greenhouse Gas data is shown on the
     dashboard.
    :type show_ghg: bool
    :param map_dashboard_filters: Filters applied to the dashboard.
    :type map_dashboard_filters: list[~energycap.sdk.models.FilterResponse]
    :param global_commodity_display: Display order for commodities. Applied
     individually to Cost, Use, and GHG Emissions.
     Highest - Order displayed commodities in order of Highest Cost/Use/GHG
     Emissions
     Lowest - Order displayed commodities in order Lowest Cost/Use/GHG
     Emissions
     Fixed - Display up to 5 fixed commodities for each data type.
    :type global_commodity_display: str
    :param fixed_commodities: List of Commodities to display for Cost, Use,
     and GHG, if applicable. Empty if GlobalCommodityDisplay is set to
     "Highest" or "Lowest".
    :type fixed_commodities: list[~energycap.sdk.models.CommodityChild]
    """

    _attribute_map = {
        'title': {'key': 'title', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'show_cost': {'key': 'showCost', 'type': 'bool'},
        'show_use': {'key': 'showUse', 'type': 'bool'},
        'show_ghg': {'key': 'showGHG', 'type': 'bool'},
        'map_dashboard_filters': {'key': 'mapDashboardFilters', 'type': '[FilterResponse]'},
        'global_commodity_display': {'key': 'globalCommodityDisplay', 'type': 'str'},
        'fixed_commodities': {'key': 'fixedCommodities', 'type': '[CommodityChild]'},
    }

    def __init__(self, *, title: str=None, description: str=None, show_cost: bool=None, show_use: bool=None, show_ghg: bool=None, map_dashboard_filters=None, global_commodity_display: str=None, fixed_commodities=None, **kwargs) -> None:
        super(MapDashboardSettingsResponse, self).__init__(**kwargs)
        self.title = title
        self.description = description
        self.show_cost = show_cost
        self.show_use = show_use
        self.show_ghg = show_ghg
        self.map_dashboard_filters = map_dashboard_filters
        self.global_commodity_display = global_commodity_display
        self.fixed_commodities = fixed_commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Commodity(Model):
    """Commodity.

    :param commodity_id: The Commodity ID
    :type commodity_id: int
    :param commodity_code: The Commodity Code
    :type commodity_code: str
    :param commodity_info: The Commodity Info
    :type commodity_info: str
    :param in_use_by_vendor: Flag to indicate if the commodity is assigned to
     any meters
    :type in_use_by_vendor: bool
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param common_demand_unit:
    :type common_demand_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'in_use_by_vendor': {'key': 'inUseByVendor', 'type': 'bool'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'common_demand_unit': {'key': 'commonDemandUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(Commodity, self).__init__(**kwargs)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.commodity_code = kwargs.get('commodity_code', None)
        self.commodity_info = kwargs.get('commodity_info', None)
        self.in_use_by_vendor = kwargs.get('in_use_by_vendor', None)
        self.common_use_unit = kwargs.get('common_use_unit', None)
        self.common_demand_unit = kwargs.get('common_demand_unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGScopeResponse(Model):
    """GHGScopeResponse.

    :param scope_id: The Scope Identifier
    :type scope_id: int
    :param scope_info: The Scope Info
    :type scope_info: str
    :param scope_categories: The list of Scope Categories under this scope
    :type scope_categories: list[~energycap.sdk.models.GHGScopeCategoryChild]
    """

    _attribute_map = {
        'scope_id': {'key': 'scopeId', 'type': 'int'},
        'scope_info': {'key': 'scopeInfo', 'type': 'str'},
        'scope_categories': {'key': 'scopeCategories', 'type': '[GHGScopeCategoryChild]'},
    }

    def __init__(self, **kwargs):
        super(GHGScopeResponse, self).__init__(**kwargs)
        self.scope_id = kwargs.get('scope_id', None)
        self.scope_info = kwargs.get('scope_info', None)
        self.scope_categories = kwargs.get('scope_categories', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleWithHiddenRequest(Model):
    """SystemUserRoleWithHiddenRequest.

    All required parameters must be populated in order to send to Azure.

    :param hidden: Set a system user role to be hidden or shown
     Roles Manage permission is required to access hidden roles
    :type hidden: bool
    :param system_user_role_name: Required. Name of the system user role <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type system_user_role_name: str
    :param description: Required. Description of the system user role <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 1000 characters</span>
    :type description: str
    :param permissions:
    :type permissions: ~energycap.sdk.models.PermissionsRequest
    """

    _validation = {
        'system_user_role_name': {'required': True, 'max_length': 64, 'min_length': 0},
        'description': {'required': True, 'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'hidden': {'key': 'hidden', 'type': 'bool'},
        'system_user_role_name': {'key': 'systemUserRoleName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'permissions': {'key': 'permissions', 'type': 'PermissionsRequest'},
    }

    def __init__(self, **kwargs):
        super(SystemUserRoleWithHiddenRequest, self).__init__(**kwargs)
        self.hidden = kwargs.get('hidden', None)
        self.system_user_role_name = kwargs.get('system_user_role_name', None)
        self.description = kwargs.get('description', None)
        self.permissions = kwargs.get('permissions', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorCategoryResponse(Model):
    """GHGFactorCategoryResponse.

    :param factors: The Factors attached to a Category
    :type factors: list[~energycap.sdk.models.GHGFactorByCategoryChild]
    :param factor_category_id: The Factor Category identifier
    :type factor_category_id: int
    :param factor_category_info: The Factor Category Info
    :type factor_category_info: str
    """

    _attribute_map = {
        'factors': {'key': 'factors', 'type': '[GHGFactorByCategoryChild]'},
        'factor_category_id': {'key': 'factorCategoryId', 'type': 'int'},
        'factor_category_info': {'key': 'factorCategoryInfo', 'type': 'str'},
    }

    def __init__(self, *, factors=None, factor_category_id: int=None, factor_category_info: str=None, **kwargs) -> None:
        super(GHGFactorCategoryResponse, self).__init__(**kwargs)
        self.factors = factors
        self.factor_category_id = factor_category_id
        self.factor_category_info = factor_category_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupCategoryChild(Model):
    """MeterGroupCategoryChild.

    :param meter_group_category_id:
    :type meter_group_category_id: int
    :param meter_group_category_code:
    :type meter_group_category_code: str
    :param meter_group_category_info:
    :type meter_group_category_info: str
    """

    _attribute_map = {
        'meter_group_category_id': {'key': 'meterGroupCategoryId', 'type': 'int'},
        'meter_group_category_code': {'key': 'meterGroupCategoryCode', 'type': 'str'},
        'meter_group_category_info': {'key': 'meterGroupCategoryInfo', 'type': 'str'},
    }

    def __init__(self, *, meter_group_category_id: int=None, meter_group_category_code: str=None, meter_group_category_info: str=None, **kwargs) -> None:
        super(MeterGroupCategoryChild, self).__init__(**kwargs)
        self.meter_group_category_id = meter_group_category_id
        self.meter_group_category_code = meter_group_category_code
        self.meter_group_category_info = meter_group_category_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodRangeComparison(Model):
    """General purpose period range comparison DTO.

    :param current_period_range:
    :type current_period_range: ~energycap.sdk.models.PeriodRange
    :param previous_period_range:
    :type previous_period_range: ~energycap.sdk.models.PeriodRange
    """

    _attribute_map = {
        'current_period_range': {'key': 'currentPeriodRange', 'type': 'PeriodRange'},
        'previous_period_range': {'key': 'previousPeriodRange', 'type': 'PeriodRange'},
    }

    def __init__(self, *, current_period_range=None, previous_period_range=None, **kwargs) -> None:
        super(PeriodRangeComparison, self).__init__(**kwargs)
        self.current_period_range = current_period_range
        self.previous_period_range = previous_period_range



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Target(Model):
    """Target.

    :param enable: Is the target setting enabled
    :type enable: bool
    :param multiplier: What multiplier to use for the target
    :type multiplier: float
    """

    _attribute_map = {
        'enable': {'key': 'enable', 'type': 'bool'},
        'multiplier': {'key': 'multiplier', 'type': 'float'},
    }

    def __init__(self, *, enable: bool=None, multiplier: float=None, **kwargs) -> None:
        super(Target, self).__init__(**kwargs)
        self.enable = enable
        self.multiplier = multiplier



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TrendTarget(Model):
    """Target data for use / cost / target emissions data.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param target_ytd_label: Target YTD label
    :type target_ytd_label: str
    :param target_value: Total value (use or cost) for the target year in the
     unit of the value being reported on
    :type target_value: float
    :param target_ytd_value: Year to date value (use or cost) for the target
     year in the unit of the value being reported on
    :type target_ytd_value: float
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'target_ytd_label': {'key': 'targetYTDLabel', 'type': 'str'},
        'target_value': {'key': 'targetValue', 'type': 'float'},
        'target_ytd_value': {'key': 'targetYTDValue', 'type': 'float'},
    }

    def __init__(self, *, target_year: int=None, target_label: str=None, target_ytd_label: str=None, target_value: float=None, target_ytd_value: float=None, **kwargs) -> None:
        super(TrendTarget, self).__init__(**kwargs)
        self.target_year = target_year
        self.target_label = target_label
        self.target_ytd_label = target_ytd_label
        self.target_value = target_value
        self.target_ytd_value = target_ytd_value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MapPlaceChild(Model):
    """MapPlaceChild.

    :param place_id: The identifier for place
    :type place_id: int
    :param place_code: The place code
    :type place_code: str
    :param place_info: The place information
    :type place_info: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param floor_area: The floor area of the place, reported in the global
     area unit
    :type floor_area: float
    :param primary_use:
    :type primary_use: ~energycap.sdk.models.PrimaryUseChild
    :param energy_use_intensity: Energy Use Intensity (EUI) for the past
     period
    :type energy_use_intensity: float
    :param energy_cost_intensity: Energy Cost Intensity (ECI) for the past
     period
    :type energy_cost_intensity: float
    :param ghg_intensity: Green House Gas (GHG) Intensity for the past period
    :type ghg_intensity: float
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'floor_area': {'key': 'floorArea', 'type': 'float'},
        'primary_use': {'key': 'primaryUse', 'type': 'PrimaryUseChild'},
        'energy_use_intensity': {'key': 'energyUseIntensity', 'type': 'float'},
        'energy_cost_intensity': {'key': 'energyCostIntensity', 'type': 'float'},
        'ghg_intensity': {'key': 'ghgIntensity', 'type': 'float'},
    }

    def __init__(self, *, place_id: int=None, place_code: str=None, place_info: str=None, address=None, floor_area: float=None, primary_use=None, energy_use_intensity: float=None, energy_cost_intensity: float=None, ghg_intensity: float=None, **kwargs) -> None:
        super(MapPlaceChild, self).__init__(**kwargs)
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.address = address
        self.floor_area = floor_area
        self.primary_use = primary_use
        self.energy_use_intensity = energy_use_intensity
        self.energy_cost_intensity = energy_cost_intensity
        self.ghg_intensity = ghg_intensity



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RollingComparisonResponse(Model):
    """RollingComparisonResponse.

    :param data_displayed: Indicates the type of the data displayed. Eg:
     Actual, Calendarized or Normalized.
    :type data_displayed: str
    :param unit: The values unit
    :type unit: str
    :param period_range:
    :type period_range: ~energycap.sdk.models.PeriodRange
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.RollingComparisonDetail]
    """

    _attribute_map = {
        'data_displayed': {'key': 'dataDisplayed', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'str'},
        'period_range': {'key': 'periodRange', 'type': 'PeriodRange'},
        'data_details': {'key': 'dataDetails', 'type': '[RollingComparisonDetail]'},
    }

    def __init__(self, *, data_displayed: str=None, unit: str=None, period_range=None, data_details=None, **kwargs) -> None:
        super(RollingComparisonResponse, self).__init__(**kwargs)
        self.data_displayed = data_displayed
        self.unit = unit
        self.period_range = period_range
        self.data_details = data_details



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGGas(Model):
    """GHGGas.

    :param gas_id: Gas identifier
    :type gas_id: int
    :param gas_info: Gas descrption
    :type gas_info: str
    :param gas_amount: Gas amount
    :type gas_amount: float
    :param co2_evalue: Co2Evalue
    :type co2_evalue: float
    """

    _attribute_map = {
        'gas_id': {'key': 'gasId', 'type': 'int'},
        'gas_info': {'key': 'gasInfo', 'type': 'str'},
        'gas_amount': {'key': 'gasAmount', 'type': 'float'},
        'co2_evalue': {'key': 'co2Evalue', 'type': 'float'},
    }

    def __init__(self, *, gas_id: int=None, gas_info: str=None, gas_amount: float=None, co2_evalue: float=None, **kwargs) -> None:
        super(GHGGas, self).__init__(**kwargs)
        self.gas_id = gas_id
        self.gas_info = gas_info
        self.gas_amount = gas_amount
        self.co2_evalue = co2_evalue



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestActualAndCalendarizedYearlyResponseCommodityResults(Model):
    """PlaceDigestActualAndCalendarizedYearlyResponseCommodityResults.

    :param year: year
    :type year: str
    :param total_cost: Total Cost
    :type total_cost: float
    :param common_use: Common Use
    :type common_use: float
    :param common_use_unit_cost: Common Use Unit Cost
    :type common_use_unit_cost: float
    :param global_use: Global Use
    :type global_use: float
    :param global_use_unit_cost: Global Use Unit Cost
    :type global_use_unit_cost: float
    :param common_demand: Common Demand
    :type common_demand: float
    :param common_demand_unit_cost: Common Demand Unit Cost
    :type common_demand_unit_cost: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'common_use_unit_cost': {'key': 'commonUseUnitCost', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'global_use_unit_cost': {'key': 'globalUseUnitCost', 'type': 'float'},
        'common_demand': {'key': 'commonDemand', 'type': 'float'},
        'common_demand_unit_cost': {'key': 'commonDemandUnitCost', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestActualAndCalendarizedYearlyResponseCommodityResults, self).__init__(**kwargs)
        self.year = kwargs.get('year', None)
        self.total_cost = kwargs.get('total_cost', None)
        self.common_use = kwargs.get('common_use', None)
        self.common_use_unit_cost = kwargs.get('common_use_unit_cost', None)
        self.global_use = kwargs.get('global_use', None)
        self.global_use_unit_cost = kwargs.get('global_use_unit_cost', None)
        self.common_demand = kwargs.get('common_demand', None)
        self.common_demand_unit_cost = kwargs.get('common_demand_unit_cost', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OkObjectResult(Model):
    """OkObjectResult.

    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: object
    :param formatters:  <span class='property-internal'>Required
     (defined)</span>
    :type formatters: list[object]
    :param content_types:  <span class='property-internal'>Required
     (defined)</span>
    :type content_types: list[str]
    :param declared_type:  <span class='property-internal'>Required
     (defined)</span>
    :type declared_type: str
    :param status_code:  <span class='property-internal'>Required
     (defined)</span>
    :type status_code: int
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'object'},
        'formatters': {'key': 'formatters', 'type': '[object]'},
        'content_types': {'key': 'contentTypes', 'type': '[str]'},
        'declared_type': {'key': 'declaredType', 'type': 'str'},
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(OkObjectResult, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.formatters = kwargs.get('formatters', None)
        self.content_types = kwargs.get('content_types', None)
        self.declared_type = kwargs.get('declared_type', None)
        self.status_code = kwargs.get('status_code', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGSettings(Model):
    """GHGSettings.

    :param global_warming_assessment_report_id: The GHG Global Warming
     Assessment Report (AR) identifier
    :type global_warming_assessment_report_id: int
    :param global_warming_assessment_report_info: The GHG Global Warming
     Assessment Report (AR) name
    :type global_warming_assessment_report_info: str
    :param reporting_unit:
    :type reporting_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'global_warming_assessment_report_id': {'key': 'globalWarmingAssessmentReportId', 'type': 'int'},
        'global_warming_assessment_report_info': {'key': 'globalWarmingAssessmentReportInfo', 'type': 'str'},
        'reporting_unit': {'key': 'reportingUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(GHGSettings, self).__init__(**kwargs)
        self.global_warming_assessment_report_id = kwargs.get('global_warming_assessment_report_id', None)
        self.global_warming_assessment_report_info = kwargs.get('global_warming_assessment_report_info', None)
        self.reporting_unit = kwargs.get('reporting_unit', None)
